@@ -11,16 +11,20 @@ class Topography:
         This always assumes that the topography we pass fits perfectly the extent
 
     """
-    def __init__(self, regular_grid=None, extent=None, resolution=None):
-        if regular_grid is None and (extent is None or resolution is None):
+    def __init__(self, regular_grid=None, regular_grid_extent=None, regular_grid_resolution=None):
+
+        if regular_grid is None and (regular_grid_extent is None or regular_grid_resolution is None):
             raise AttributeError('You need to pass either a regular grid or'
                                  'extent and resolution')
 
         # Set the extent and resolution of the grid
-        self.resolution = regular_grid.resolution[:2] if resolution is None else resolution
-        assert all(np.asarray(self.resolution) >= 2), 'The regular grid needs to be at least of size 2 on all ' \
+        if regular_grid_resolution is None:
+            self.regular_grid_resolution = regular_grid.resolution[:2]
+        else:
+            self.regular_grid_resolution = regular_grid_resolution
+        assert all(np.asarray(self.regular_grid_resolution) >= 2), 'The regular grid needs to be at least of size 2 on all ' \
                                                       'directions.'
-        self.extent = regular_grid.extent[:] if extent is None else extent
+        self.extent = regular_grid.extent[:] if regular_grid_extent is None else regular_grid_extent
 
         # Values (n, 3)
         self.values = np.zeros((0, 3))
@@ -31,9 +35,34 @@ class Topography:
         # Shape original
         self.raster_shape = tuple()
 
+        # Topography Resolution
+        self.resolution = np.zeros((0, 3))
+
         # Source for the
         self.source = None
 
+        # Coords
+        self._x = None
+        self._y = None
+
+    @property
+    def x(self):
+        if self._x is not None:
+            return self._x
+        else:
+            val = self.values[:, 0]
+            val.sort()
+            return np.unique(val)
+
+    @property
+    def y(self):
+        if self._y is not None:
+            return self._y
+        else:
+            val = self.values[:, 1]
+            val.sort()
+            return np.unique(val)
+
     def set_values(self, values_2d: np.ndarray):
         """General method to set topography
 
@@ -48,6 +77,7 @@ class Topography:
         """
         # Original topography data
         self.values_2d = values_2d
+        self.resolution = values_2d.shape[:2]
 
         # n,3 array
         self.values = values_2d.reshape((-1, 3), order='C')
@@ -69,7 +99,7 @@ class Topography:
     def resize_topo(self):
         regular_grid_topo = skimage.transform.resize(
             self.values_2d,
-            (self.resolution[0], self.resolution[1]),
+            (self.regular_grid_resolution[0], self.regular_grid_resolution[1]),
             mode='constant',
             anti_aliasing=False, preserve_range=True)
 
@@ -80,15 +110,17 @@ class Topography:
             self.extent = kwargs.pop('extent')
 
         if 'resolution' in kwargs:
-            self.resolution = kwargs.pop('resolution')
+            self.regular_grid_resolution = kwargs.pop('resolution')
 
         dem = LoadDEMArtificial(extent=self.extent,
-                                resolution=self.resolution, **kwargs)
+                                resolution=self.regular_grid_resolution, **kwargs)
 
+        self._x, self._y = dem.x, dem.y
         self.set_values(dem.get_values())
 
     def load_from_gdal(self, filepath):
         dem = LoadDEMGDAL(filepath, extent=self.extent)
+        self._x, self._y = None, None
         self.set_values(dem.get_values())
         # self.source = 'gdal'
 
@@ -97,6 +129,7 @@ class Topography:
 
     def load(self, path):
         self.set_values(np.load(path))
+        self._x, self._y = None, None
         return self.values
 
     def load_from_saved(self, *args, **kwargs):
